@@ -35,34 +35,36 @@
         <location filename="../main.cpp" line="42"/>
         <location filename="../main.cpp" line="50"/>
         <source>Pop-up with exit options for MX Fluxbox</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Fluxbox の終了ポップアップ表示オプション</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="43"/>
         <source>Display buttons in a vertical window</source>
-        <translation type="unfinished"></translation>
+        <translation>垂直方向のウインドウにボタンを表示する</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="44"/>
         <source>Display buttons in a horizontal window</source>
-        <translation type="unfinished"></translation>
+        <translation>水平方向のウインドウにボタンを表示する</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="45"/>
         <source>Timeout duration in seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>タイムアウトまでの秒数</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="46"/>
         <source>use -v, --vertical to display buttons vertically
 use -h, --horizontal to display buttons horizontally.</source>
-        <translation type="unfinished"></translation>
+        <translation>ボタンを縦方向に表示するには -v, --vertical を指定します。
+ボタンを水平方向に表示するには -h, --horizontal を指定します。</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Usage: exit-options [options]
 </source>
-        <translation type="unfinished"></translation>
+        <translation>使い方: exit-options [オプション]
+</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="52"/>
@@ -72,38 +74,39 @@ use -h, --horizontal to display buttons horizontally.</source>
     <message>
         <location filename="../main.cpp" line="53"/>
         <source>  -h, --horizontal	 Option to display buttons horizontally</source>
-        <translation type="unfinished"></translation>
+        <translation>  -h, --horizontal	 水平方向にボタンを表示するオプション</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="54"/>
         <source>  -v, --vertical	 Option to display buttons vertically</source>
-        <translation type="unfinished"></translation>
+        <translation>  -v, --vertical	 垂直方向にボタンを表示するオプション</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="55"/>
         <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
 </source>
-        <translation type="unfinished"></translation>
+        <translation>  -t, --timeout &lt;sec&gt;	 タイムアウトまでの秒数
+</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="56"/>
         <source>The display orientation option used will be remembered and used the next time you start the app</source>
-        <translation type="unfinished"></translation>
+        <translation>一度設定したディスプレイの向きは保存され、次回起動時にも使用します</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
-        <translation type="unfinished"></translation>
+        <translation>次のように設定しても同じです。 &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="62"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>カスタムアイコンを定義するには exit-options.conf ファイルに IconName=/path/iconame.ext というように記述します。再マッピングするアイコン名: %1</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>exit-options.conf ファイルで設定可能なその他のオプション: %1</translation>
     </message>
 </context>
 </TS>
